Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
analyzers / __init__.py |  | 0 | 0 | 0 |  | 100%
analyzers / common.py |  | 53 | 0 | 0 |  | 100%
analyzers / go.py |  | 13 | 1 | 0 |  | 92%
analyzers / python.py |  | 14 | 1 | 0 |  | 93%
analyzers / shared.py |  | 15 | 7 | 0 |  | 53%
analyzers / typescript.py |  | 21 | 3 | 0 |  | 86%
call_graph / __init__.py |  | 4 | 0 | 0 |  | 100%
call_graph / core.py |  | 73 | 5 | 0 |  | 93%
call_graph / formatters.py |  | 40 | 8 | 0 |  | 80%
call_graph / parsers / __init__.py |  | 4 | 0 | 0 |  | 100%
call_graph / parsers / base.py |  | 10 | 2 | 2 |  | 80%
call_graph / parsers / python.py |  | 124 | 12 | 0 |  | 90%
circular_deps / __init__.py |  | 3 | 0 | 0 |  | 100%
circular_deps / core.py |  | 188 | 80 | 2 |  | 57%
circular_deps / formatter.py |  | 24 | 1 | 2 |  | 96%
circular_deps / models.py |  | 22 | 0 | 0 |  | 100%
circular_deps / parsers / __init__.py |  | 4 | 0 | 0 |  | 100%
circular_deps / parsers / base.py |  | 7 | 1 | 2 |  | 86%
circular_deps / parsers / go.py |  | 34 | 0 | 0 |  | 100%
circular_deps / parsers / python.py |  | 88 | 32 | 0 |  | 64%
circular_deps / parsers / typescript.py |  | 54 | 15 | 0 |  | 72%
circular_deps / resolvers / __init__.py |  | 4 | 0 | 0 |  | 100%
circular_deps / resolvers / base.py |  | 7 | 1 | 2 |  | 86%
circular_deps / resolvers / go.py |  | 51 | 3 | 0 |  | 94%
circular_deps / resolvers / python.py |  | 54 | 25 | 0 |  | 54%
circular_deps / resolvers / tsconfig.py |  | 44 | 5 | 0 |  | 89%
circular_deps / resolvers / typescript.py |  | 162 | 43 | 0 |  | 73%
common.py |  | 126 | 11 | 0 |  | 91%
dead_code / __init__.py |  | 0 | 0 | 0 |  | 100%
dead_code / core.py |  | 125 | 101 | 2 |  | 19%
dead_code / parsers / __init__.py |  | 0 | 0 | 0 |  | 100%
dead_code / parsers / base.py |  | 44 | 5 | 2 |  | 89%
dead_code / parsers / go.py |  | 130 | 41 | 0 |  | 68%
dead_code / parsers / python.py |  | 87 | 40 | 0 |  | 54%
dead_code / parsers / typescript.py |  | 192 | 55 | 0 |  | 71%
fmt.py |  | 80 | 15 | 0 |  | 81%
metrics / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / cognitive / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / cognitive / common.py |  | 6 | 0 | 0 |  | 100%
metrics / cognitive / go.py |  | 71 | 9 | 0 |  | 87%
metrics / cognitive / python.py |  | 88 | 10 | 0 |  | 89%
metrics / cognitive / typescript.py |  | 79 | 9 | 0 |  | 89%
metrics / cyclomatic / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / cyclomatic / go.py |  | 13 | 1 | 0 |  | 92%
metrics / cyclomatic / python.py |  | 13 | 2 | 0 |  | 85%
metrics / cyclomatic / shared.py |  | 18 | 0 | 0 |  | 100%
metrics / cyclomatic / typescript.py |  | 11 | 0 | 0 |  | 100%
metrics / dtd / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / dtd / go.py |  | 39 | 6 | 0 |  | 85%
metrics / dtd / python.py |  | 45 | 3 | 0 |  | 93%
metrics / dtd / typescript.py |  | 69 | 5 | 0 |  | 93%
metrics / duplication / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / duplication / config.py |  | 10 | 0 | 0 |  | 100%
metrics / duplication / core.py |  | 100 | 1 | 0 |  | 99%
metrics / halstead / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / halstead / common.py |  | 28 | 0 | 0 |  | 100%
metrics / halstead / go.py |  | 7 | 0 | 0 |  | 100%
metrics / halstead / python.py |  | 7 | 0 | 0 |  | 100%
metrics / halstead / typescript.py |  | 7 | 0 | 0 |  | 100%
metrics / lloc / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / lloc / go.py |  | 13 | 0 | 0 |  | 100%
metrics / lloc / python.py |  | 9 | 0 | 0 |  | 100%
metrics / lloc / typescript.py |  | 12 | 0 | 0 |  | 100%
metrics / npath / __init__.py |  | 0 | 0 | 0 |  | 100%
metrics / npath / go.py |  | 132 | 14 | 0 |  | 89%
metrics / npath / python.py |  | 158 | 12 | 0 |  | 92%
metrics / npath / typescript.py |  | 167 | 16 | 0 |  | 90%
models.py |  | 83 | 0 | 0 |  | 100%
parsers / __init__.py |  | 0 | 0 | 0 |  | 100%
parsers / common.py |  | 6 | 0 | 0 |  | 100%
parsers / go.py |  | 53 | 14 | 0 |  | 74%
parsers / python.py |  | 18 | 1 | 0 |  | 94%
parsers / shared.py |  | 12 | 0 | 0 |  | 100%
parsers / typescript.py |  | 36 | 3 | 0 |  | 92%
patterns / __init__.py |  | 10 | 7 | 0 |  | 30%
patterns / common.py |  | 18 | 0 | 2 |  | 100%
patterns / python.py |  | 42 | 6 | 1 |  | 86%
patterns / shared.py |  | 17 | 6 | 2 |  | 65%
perf.py |  | 23 | 8 | 0 |  | 65%
tests / test_call_graph / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_call_graph / test_cycles.py |  | 31 | 0 | 0 |  | 100%
tests / test_call_graph / test_formatters.py |  | 28 | 0 | 0 |  | 100%
tests / test_call_graph / test_parser.py |  | 53 | 0 | 0 |  | 100%
tests / test_call_graph / test_resolution.py |  | 40 | 0 | 0 |  | 100%
tests / test_call_graph / test_unused.py |  | 71 | 0 | 0 |  | 100%
tests / test_circular_deps / test_core.py |  | 112 | 0 | 0 |  | 100%
tests / test_circular_deps / test_go.py |  | 152 | 0 | 0 |  | 100%
tests / test_circular_deps / test_typescript.py |  | 257 | 0 | 0 |  | 100%
tests / test_cognitive / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_cognitive / test_go.py |  | 109 | 0 | 0 |  | 100%
tests / test_cognitive / test_python.py |  | 97 | 0 | 0 |  | 100%
tests / test_cognitive / test_typescript.py |  | 107 | 0 | 0 |  | 100%
tests / test_common.py |  | 98 | 0 | 0 |  | 100%
tests / test_dead_code_core.py |  | 42 | 0 | 0 |  | 100%
tests / test_dead_code_go.py |  | 101 | 0 | 0 |  | 100%
tests / test_dead_code_typescript.py |  | 170 | 1 | 0 |  | 99%
tests / test_dtd / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_dtd / test_go.py |  | 28 | 0 | 0 |  | 100%
tests / test_dtd / test_python.py |  | 36 | 0 | 0 |  | 100%
tests / test_dtd / test_typescript.py |  | 36 | 0 | 0 |  | 100%
tests / test_duplication / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_duplication / test_core.py |  | 221 | 0 | 0 |  | 100%
tests / test_fmt.py |  | 108 | 0 | 0 |  | 100%
tests / test_halstead / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_halstead / test_go.py |  | 24 | 0 | 0 |  | 100%
tests / test_halstead / test_python.py |  | 25 | 0 | 0 |  | 100%
tests / test_halstead / test_typescript.py |  | 23 | 0 | 0 |  | 100%
tests / test_mi / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_mi / test_go.py |  | 36 | 0 | 0 |  | 100%
tests / test_mi / test_python.py |  | 36 | 0 | 0 |  | 100%
tests / test_mi / test_typescript.py |  | 36 | 0 | 0 |  | 100%
tests / test_npath / __init__.py |  | 0 | 0 | 0 |  | 100%
tests / test_npath / test_go.py |  | 73 | 0 | 0 |  | 100%
tests / test_npath / test_python.py |  | 75 | 0 | 0 |  | 100%
tests / test_npath / test_typescript.py |  | 81 | 0 | 0 |  | 100%
tests / test_patterns / test_python.py |  | 28 | 0 | 0 |  | 100%
Total |  | 5655 | 647 | 19 |  | 89%

No items found using the specified filter.